@@ -40,8 +40,7 @@
 #include <thrust/iterator/iterator_traits.h>
 #include <thrust/detail/type_traits.h>
 
-namespace thrust
-{
+THRUST_NAMESPACE_BEGIN
 
 /*! \addtogroup iterators
  *  \{
@@ -312,7 +311,7 @@ template <class AdaptableUnaryFunction, class Iterator, class Reference = use_de
       // Create a temporary to allow iterators with wrapped references to
       // convert to their value type before calling m_f. Note that this
       // disallows non-constant operations through m_f.
-      typename thrust::iterator_value<Iterator>::type x = *this->base();
+      typename thrust::iterator_value<Iterator>::type const& x = *this->base();
       return m_f(x);
     }
 
@@ -352,5 +351,5 @@ make_transform_iterator(Iterator it, AdaptableUnaryFunction fun)
 /*! \} // end iterators
  */
 
-} // end thrust
+THRUST_NAMESPACE_END
 
