@@ -20,14 +20,14 @@
 
 #pragma once
 
+#include <thrust/detail/config.h>
 #include <thrust/detail/cpp11_required.h>
 
 #if THRUST_CPP_DIALECT >= 2011
 
 #include <thrust/mr/disjoint_pool.h>
 
-namespace thrust
-{
+THRUST_NAMESPACE_BEGIN
 namespace mr
 {
 
@@ -63,7 +63,7 @@ thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper> & tls_di
  */
 
 } // end mr
-} // end thrust
+THRUST_NAMESPACE_END
 
 #endif // THRUST_CPP_DIALECT >= 2011
 
