@@ -1,5 +1,5 @@
 /*
- *  Copyright 2008-2018 NVIDIA Corporation
+ *  Copyright 2008-2021 NVIDIA Corporation
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -14,19 +14,22 @@
  *  limitations under the License.
  */
 
-/*! \file is_contiguous_iterator.h
- *  \brief An extensible type trait for determining if an iterator satisifies
- *         the <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>
- *         requirements (e.g. is pointer-like).
+/*! \file
+ *  \brief An extensible type trait for determining if an iterator satisifies the
+ *  <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>
+ *  requirements (aka is pointer-like).
  */
 
 #pragma once
 
 #include <thrust/detail/config.h>
+#include <thrust/detail/raw_pointer_cast.h>
 #include <thrust/detail/type_traits.h>
 #include <thrust/detail/type_traits/pointer_traits.h>
 
 #include <iterator>
+#include <type_traits>
+#include <utility>
 
 #if THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC && _MSC_VER < 1916 // MSVC 2017 version 15.9
   #include <vector>
@@ -40,6 +43,17 @@
 
 THRUST_NAMESPACE_BEGIN
 
+/*! \addtogroup utility
+ *  \{
+ */
+
+/*! \addtogroup type_traits Type Traits
+ *  \{
+ */
+
+/*! \cond
+ */
+
 namespace detail
 {
 
@@ -48,10 +62,19 @@ struct is_contiguous_iterator_impl;
 
 } // namespace detail
 
-/// Unary metafunction returns \c true_type if \c Iterator satisfies
-/// <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>,
-/// e.g. it points to elements that are contiguous in memory, and \c false_type
-/// otherwise.
+/*! \endcond
+ */
+
+/*! \brief <a href="https://en.cppreference.com/w/cpp/named_req/UnaryTypeTrait"><i>UnaryTypeTrait</i></a>
+ *  that returns \c true_type if \c Iterator satisfies
+ *  <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>,
+ *  aka it points to elements that are contiguous in memory, and \c false_type
+ *  otherwise.
+ *
+ * \see is_contiguous_iterator_v
+ * \see proclaim_contiguous_iterator
+ * \see THRUST_PROCLAIM_CONTIGUOUS_ITERATOR
+ */
 template <typename Iterator>
 #if THRUST_CPP_DIALECT >= 2011
 using is_contiguous_iterator =
@@ -65,24 +88,37 @@ struct is_contiguous_iterator :
 ;
 
 #if THRUST_CPP_DIALECT >= 2014
-/// <code>constexpr bool</code> that is \c true if \c Iterator satisfies
-/// <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>,
-/// e.g. it points to elements that are contiguous in memory, and \c false
-/// otherwise.
+/*! \brief <tt>constexpr bool</tt> that is \c true if \c Iterator satisfies
+ *  <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>,
+ *  aka it points to elements that are contiguous in memory, and \c false
+ *  otherwise.
+ *
+ * \see is_contiguous_iterator
+ * \see proclaim_contiguous_iterator
+ * \see THRUST_PROCLAIM_CONTIGUOUS_ITERATOR
+ */
 template <typename Iterator>
 constexpr bool is_contiguous_iterator_v = is_contiguous_iterator<Iterator>::value;
 #endif
 
-/// Customization point that can be customized to indicate that an iterator
-/// type \c Iterator satisfies
-/// <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>,
-/// e.g. it points to elements that are contiguous in memory.
+/*! \brief Customization point that can be customized to indicate that an
+ *  iterator type \c Iterator satisfies
+ *  <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>,
+ *  aka it points to elements that are contiguous in memory.
+ *
+ * \see is_contiguous_iterator
+ * \see THRUST_PROCLAIM_CONTIGUOUS_ITERATOR
+ */
 template <typename Iterator>
 struct proclaim_contiguous_iterator : false_type {};
 
-/// Declares that the iterator \c Iterator is
-/// <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>
-/// by specializing `thrust::proclaim_contiguous_iterator`.
+/*! \brief Declares that the iterator \c Iterator is
+ *  <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>
+ *  by specializing \c proclaim_contiguous_iterator.
+ *
+ * \see is_contiguous_iterator
+ * \see proclaim_contiguous_iterator
+ */
 #define THRUST_PROCLAIM_CONTIGUOUS_ITERATOR(Iterator)                         \
   THRUST_NAMESPACE_BEGIN                                                      \
   template <>                                                                 \
@@ -91,7 +127,8 @@ struct proclaim_contiguous_iterator : false_type {};
   THRUST_NAMESPACE_END                                                        \
   /**/
 
-///////////////////////////////////////////////////////////////////////////////
+/*! \cond
+ */
 
 namespace detail
 {
@@ -165,7 +202,6 @@ template <typename Iterator>
 struct is_msvc_contiguous_iterator : false_type {};
 #endif
 
-
 template <typename Iterator>
 struct is_contiguous_iterator_impl
   : integral_constant<
@@ -179,7 +215,81 @@ struct is_contiguous_iterator_impl
     >
 {};
 
+// Type traits for contiguous iterators:
+template <typename Iterator>
+struct contiguous_iterator_traits
+{
+  static_assert(thrust::is_contiguous_iterator<Iterator>::value,
+                "contiguous_iterator_traits requires a contiguous iterator.");
+
+  using raw_pointer = typename thrust::detail::pointer_traits<
+    decltype(&*std::declval<Iterator>())>::raw_pointer;
+};
+
+template <typename Iterator>
+using contiguous_iterator_raw_pointer_t =
+  typename contiguous_iterator_traits<Iterator>::raw_pointer;
+
+// Converts a contiguous iterator to a raw pointer:
+template <typename Iterator>
+__host__ __device__
+contiguous_iterator_raw_pointer_t<Iterator>
+contiguous_iterator_raw_pointer_cast(Iterator it)
+{
+  static_assert(thrust::is_contiguous_iterator<Iterator>::value,
+                "contiguous_iterator_raw_pointer_cast called with "
+                "non-contiguous iterator.");
+  return thrust::raw_pointer_cast(&*it);
+}
+
+// Implementation for non-contiguous iterators -- passthrough.
+template <typename Iterator,
+          bool IsContiguous = thrust::is_contiguous_iterator<Iterator>::value>
+struct try_unwrap_contiguous_iterator_impl
+{
+  using type = Iterator;
+
+  static __host__ __device__ type get(Iterator it) { return it; }
+};
+
+// Implementation for contiguous iterators -- unwraps to raw pointer.
+template <typename Iterator>
+struct try_unwrap_contiguous_iterator_impl<Iterator, true /*is_contiguous*/>
+{
+  using type = contiguous_iterator_raw_pointer_t<Iterator>;
+
+  static __host__ __device__ type get(Iterator it)
+  {
+    return contiguous_iterator_raw_pointer_cast(it);
+  }
+};
+
+template <typename Iterator>
+using try_unwrap_contiguous_iterator_return_t =
+  typename try_unwrap_contiguous_iterator_impl<Iterator>::type;
+
+// Casts to a raw pointer if iterator is marked as contiguous, otherwise returns
+// the input iterator.
+template <typename Iterator>
+__host__ __device__
+try_unwrap_contiguous_iterator_return_t<Iterator>
+try_unwrap_contiguous_iterator(Iterator it)
+{
+  return try_unwrap_contiguous_iterator_impl<Iterator>::get(it);
+}
+
 } // namespace detail
 
+/*! \endcond
+ */
+
+///////////////////////////////////////////////////////////////////////////////
+
+/*! \} // type traits
+ */
+
+/*! \} // utility
+ */
+
 THRUST_NAMESPACE_END
 
